@@ -3,10 +3,10 @@
 # SPDX-License-Identifier: Unlicense
 import time
 import board
-import busio
 import adafruit_tmp117
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 tmp117 = adafruit_tmp117.TMP117(i2c)
 
 while True:
